/*
 *  Copyright 2013 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * This class controls a open tool ribbon button that is able to check for conditions on
 * the visibility of a Query.
 * @private
 */
Ext.define('Ametys.plugins.queriesdirectory.controllers.OpenQueryRightsToolController', {
	extend: 'Ametys.ribbon.element.ui.button.OpenToolButtonController',
	
	/**
	 * @cfg {String} selection-enable-owner-only=false If 'true' the button will be disabled as soon as the current user is not the query owner
	 */
	/**
	 * @cfg {String} selection-description-notowner The description when the current user is not the query owner but #cfg-selection-enable-owner-only is true.
	 */
	/**
	 * @cfg {String} enable-on-writeaccess-only=false If 'true' the button will be disabled as soon as the current user has no write access on query selection
	 */
	/**
	 * @cfg {String} description-no-writeaccess The description when the current user has no write access on query selection but #cfg-enable-on-writeaccess-only is true.
	 */
	/**
	 * @cfg {String} selection-enable-on-visibility-only=null If not null, the button will be disabled as soon as the current query has not the expected visibility
	 */
	/**
	 * @cfg {String} description-no-match-visibility The description when the current query has not the expected visibility
	 */
	
	constructor: function (config)
	{
		this.callParent(arguments);
		Ametys.message.MessageBus.on(Ametys.message.Message.MODIFIED, this._onQueryModified, this);
	},
	
	additionalErrorDescriptionOnSelectionChanged: function(targets)
	{
		var enableOnAdministrator = this.getInitialConfig("selection-enable-administrator") == 'true';
		var isAdministrator = enableOnAdministrator && targets[0].getParameters().isAdministrator;
		
		var enableOnOwnerOnly = this.getInitialConfig("selection-enable-owner-only") == 'true';
		if (!isAdministrator && enableOnOwnerOnly && targets[0].getParameters().authorLogin !=  Ametys.getAppParameter('user').login)
		{
			return this.getInitialConfig('selection-description-notowner') || '';
		}
		
		var enabledOnWriteAccessOnly = this.getInitialConfig("enable-on-writeaccess-only") == 'true';
		if (!isAdministrator && enabledOnWriteAccessOnly && !targets[0].getParameters().canWrite)
		{
			return this.getInitialConfig('description-no-writeaccess') || '';
		}
		
		var enableOnVisibilityOnly = this.getInitialConfig("selection-enable-on-visibility-only");
		if (enableOnVisibilityOnly != null  && targets[0].getParameters().visibility != enableOnVisibilityOnly)
		{
			return this.getInitialConfig('description-no-match-visibility') || '';
		}
	},
	
	/**
	 * Listener on modified message.
	 * Update the state of the controller accordingly.
	 * @param {Ametys.message.Message} message the message of type modified.
	 * @private
	 */
	_onQueryModified: function(message)
	{
		this.updateTargetsInCurrentSelectionTargets (message);
	}
});
	
